import {
  select,
  json,
  cluster,
  hierarchy,
  linkHorizontal,
  zoom,
  event
} from 'd3';

  const svg = d3.select('svg');
  const width = document.body.clientWidth;
  const height = document.body.clientHeight;

  const margin = { top: 400, right: 0, bottom: 0, left: 480};
  const innerHeight = height - margin.top - margin.bottom;

  const treeLayout = d3.cluster().size([2*Math.PI, innerHeight/3*2]);
  const fontSize = d3.scaleSqrt().range([30, 15]);

  const zoomG = svg
      .attr('width', width)
      .attr('height', height)
    .append('g');

  const g = zoomG.append('g')
      .attr('transform', `translate(${margin.left},${margin.top})`);

  svg.call(d3.zoom().on('zoom', () => {
    zoomG.attr('transform', d3.event.transform);
  }));

  d3.json('data.json')
    .then(data => {
      const root = d3.hierarchy(data);
      const links = treeLayout(root).links();
      const linkPathGenerator = d3.linkRadial()
          .angle(d => d.x)
          .radius(d => d.y);
        
      g.selectAll('path').data(links)
        .enter().append('path')
          .attr('d', linkPathGenerator);
    
      g.selectAll('text').data(root.descendants())
        .enter().append('text')
          .attr("x", d => d.x > Math.PI ? -d.y : d.y)
          .attr("dx", function (d){
              if(d.depth === 3){
                return (d.x > Math.PI) ? "-2px" : "2px";
              } else {
                return "0px";
              }
            })
          .attr('dy', '0.32em')
          .attr("text-anchor", function (d){
              if(d.depth === 3){
                return (d.x > Math.PI) ? "end" : "start";
              } else {
                return "middle";
              }
            })
          .attr("transform", function(d) {
              var theta = d.x / Math.PI * 180 - 90;
              if(d.x > Math.PI){
                theta += 180;
              }
              if(d.depth > 0){
                return "rotate(" + theta + ")";
              } else {
                return "";
              }
            })
          .attr("font-size", function (d){
              return fontSize(d.depth) + "pt";
            })
          .text(d => d.data.data.id);
    });